# Generated by roxygen2: do not edit by hand

S3method(AIC,simplexregression)
S3method(BIC,simplexregression)
S3method(HQIC,simplexregression)
S3method(bread,simplexregression)
S3method(coef,simplexregression)
S3method(coeftest,simplexregression)
S3method(cooks.distance,simplexregression)
S3method(deviance,simplexregression)
S3method(df.residual,simplexregression)
S3method(estfun,simplexregression)
S3method(fitted,simplexregression)
S3method(formula,simplexregression)
S3method(gleverage,simplexregression)
S3method(hatvalues,simplexregression)
S3method(logLik,simplexregression)
S3method(lrtest,simplexregression)
S3method(model.frame,simplexregression)
S3method(model.matrix,simplexregression)
S3method(nobs,simplexregression)
S3method(plot,simplexregression)
S3method(predict,simplexregression)
S3method(print,simplexregression)
S3method(print,summary.simplexregression)
S3method(residuals,simplexregression)
S3method(simulate,simplexregression)
S3method(summary,simplexregression)
S3method(terms,simplexregression)
S3method(update,simplexregression)
S3method(vcov,simplexregression)
export(HQIC)
export(dev.unit.simplex)
export(diag.distances)
export(diag.im)
export(dispersion_link)
export(dispersion_link_deriv1)
export(dispersion_link_inv)
export(dispersion_link_inv_deriv1)
export(dsimplex)
export(fixed_mean_link)
export(fixed_mean_link_deriv1)
export(fixed_mean_link_deriv2)
export(fixed_mean_link_inv)
export(fixed_mean_link_inv_deriv1)
export(gleverage)
export(halfnormal.plot)
export(local.influence)
export(parametric_mean_link)
export(parametric_mean_link_deriv1)
export(parametric_mean_link_deriv2)
export(parametric_mean_link_inv)
export(parametric_mean_link_inv_deriv1)
export(penalized.ic)
export(penalized.ss)
export(press)
export(psimplex)
export(qsimplex)
export(r2)
export(resettest)
export(rsimplex)
export(scoretest)
export(simplexreg)
export(simplexreg.control)
export(simplexreg.fit)
export(variance.simplex)
importFrom(Formula,as.Formula)
importFrom(Matrix,nearPD)
importFrom(graphics,abline)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,matplot)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(graphics,text)
importFrom(lmtest,coeftest)
importFrom(lmtest,lrtest)
importFrom(moments,skewness)
importFrom(parallel,clusterEvalQ)
importFrom(parallel,clusterExport)
importFrom(parallel,clusterSetRNGStream)
importFrom(parallel,detectCores)
importFrom(parallel,makeCluster)
importFrom(parallel,parLapply)
importFrom(parallel,stopCluster)
importFrom(pracma,quadgk)
importFrom(sandwich,bread)
importFrom(sandwich,estfun)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,cooks.distance)
importFrom(stats,cor)
importFrom(stats,dcauchy)
importFrom(stats,delete.response)
importFrom(stats,deviance)
importFrom(stats,dlogis)
importFrom(stats,dnorm)
importFrom(stats,formula)
importFrom(stats,hatvalues)
importFrom(stats,integrate)
importFrom(stats,lm.fit)
importFrom(stats,lm.wfit)
importFrom(stats,logLik)
importFrom(stats,median)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.offset)
importFrom(stats,model.response)
importFrom(stats,model.weights)
importFrom(stats,na.omit)
importFrom(stats,na.pass)
importFrom(stats,nobs)
importFrom(stats,optim)
importFrom(stats,pcauchy)
importFrom(stats,pchisq)
importFrom(stats,pgamma)
importFrom(stats,plogis)
importFrom(stats,pnorm)
importFrom(stats,printCoefmat)
importFrom(stats,qcauchy)
importFrom(stats,qlogis)
importFrom(stats,qnorm)
importFrom(stats,qqline)
importFrom(stats,qqnorm)
importFrom(stats,quantile)
importFrom(stats,rchisq)
importFrom(stats,residuals)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,simulate)
importFrom(stats,terms)
importFrom(stats,uniroot)
importFrom(stats,update)
importFrom(stats,vcov)
importFrom(stats,weighted.mean)
importFrom(utils,modifyList)
