% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/simplexreg_fit.R
\name{simplexreg.control}
\alias{simplexreg.control}
\title{Control Parameters for Simplex Regression}
\usage{
simplexreg.control(
  method = "BFGS",
  maxit = 5000,
  gradient = TRUE,
  hessian = FALSE,
  trace = FALSE,
  start = NULL,
  fsmaxit = 500,
  fstol = 1e-08,
  reltol = .Machine$double.eps^(0.5),
  ...
)
}
\arguments{
\item{method}{Characters string specifying the method argument passed to \code{optim}
(default: "BFGS").}

\item{maxit}{Integer specifying the maximum number of iterations for \code{optim}
(default: 5000).}

\item{gradient}{Logical; use analytical gradient? (default: TRUE).}

\item{hessian}{Logical; compute Hessian via \code{optim}? (default: FALSE).}

\item{trace}{Logical; trace optimization? (default: FALSE).}

\item{start}{An optional vector with starting values for all parameters.}

\item{fsmaxit}{Integer specifying maximal number of additional Fisher scoring
iterations (default: 500).}

\item{fstol}{Numeric tolerance for convergence in Fisher scoring (default: 1e-8).}

\item{reltol}{Relative convergence tolerance (default: 1e-8).}

\item{...}{Additional parameters passed to \code{optim}.}
}
\value{
A list of control parameters.
}
\description{
Auxiliary function for controlling simplex regression fitting.
}
\details{
All parameters in \code{\link{simplexreg}} are estimated by maximum likelihood using
\code{\link{optim}} with control options set in \code{\link{simplexreg.control}}.
Most arguments are passed on directly to \code{optim}, and \code{start} controls
how \code{optim} is called.

After the \code{optim} maximization, an additional Fisher scoring iteration can
be performed to further enhance the result by moving the gradient even closer to zero.
If \code{fsmaxit} is greater than zero, this additional optimization is performed and
it converges if the threshold \code{fstol} is attained for the absolute value of the
step size.

Starting values can be supplied via \code{start} or estimated by \code{\link{lm.wfit}},
using the link-transformed response. For parametric mean link functions (\code{plogit1},
\code{plogit2}), the link parameter \eqn{\lambda} is jointly estimated with the regression
coefficients. Covariances are derived analytically using the expected Fisher information
matrix. The Fisher scoring uses analytical gradients and the expected information matrix to
refine the maximum likelihood estimates obtained from \code{optim}.

The main parameters of interest are the coefficients \eqn{\beta} in the linear predictor of
the mean submodel and the coefficients \eqn{\delta} in the linear predictor of the dispersion
submodel. For parametric links, the additional link parameter \eqn{\lambda} is also
estimated and reported. The dispersion parameter \eqn{\sigma^2} can be modeled either
as constant (when the dispersion formula contains only an intercept) or as varying
across observations through a linear predictor.
}
\seealso{
\code{\link{simplexreg}}
}
