% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/simplexreg_fit.R
\name{simplexreg.nul}
\alias{simplexreg.nul}
\title{Null Model Log-Likelihood for Simplex Regression}
\usage{
simplexreg.nul(y, link.mu, weights = NULL)
}
\arguments{
\item{y}{Numeric response vector (0 < y < 1).}

\item{link.mu}{Mean link function: parametric ("plogit1", "plogit2") or fixed
("logit", "probit", "loglog", "cloglog", "cauchit").}

\item{weights}{Optional vector of weights (default: NULL).}
}
\value{
Numeric value of the null model log-likelihood
}
\description{
Computes the log-likelihood for the null (intercept-only) for a
simplex regression with a parametric or fixed mean link.
}
\keyword{internal}
